# Talks and Documents

:::{warning}

`pycompwa` is no longer maintained. Use the
[ComPWA](https://compwa-org.rtfd.io) packages [QRules](https://qrules.rtfd.io),
[AmpForm](https://ampform.rtfd.io), and
[TensorWaves](https://tensorwaves.rtfd.io) instead!

:::

## Talks

<!-- cspell:ignore CHEP Flecken Frühjahrs Tagung Zechlin -->
<!-- markdownlint-disable -->

| Event                | Title                                                                     | Location          | Year |
| -------------------- | ------------------------------------------------------------------------- | ----------------- | ---- |
| DPG Frühjahrs-Tagung | Status of the framework development for Panda PWA([pdf][talk1])           | Mainz             | 2012 |
| HGSHireGraduate Days | Partial Wave Analysis Software for PANDA ([pdf][talk2])                   | Mainz             | 2012 |
| Amp School           | Status of the Partial Wave Analysis Framework forPANDA ([pdf][talk3])     | Flecken-Zechlin   | 2013 |
| CHEP                 | ComPWA: A common Partial Wave Analysis Framework for PANDA ([pdf][talk4]) | Amsterdam         | 2013 |
| DPG Frühjahrs-Tagung | ComPWA: A common Partial Wave Analysis Framework for PANDA ([pdf][talk5]) | Frankfurt am Main | 2014 |
| DPG Frühjahrs-Tagung | ComPWA Status ([pdf][talk6])                                              | Heidelberg        | 2015 |

<!-- markdownlint-enable -->

## Poster

<!-- cspell:ignore tabularcolumns Münster Partialwellenanalyse -->
<!-- markdownlint-disable -->

| Event                | Year | Location      | Title                                                                                                   |
| -------------------- | ---- | ------------- | ------------------------------------------------------------------------------------------------------- |
| CHEP                 | 2010 | Taipei        | [Partial Wave Analysis with Geneva](https://github.com/ComPWA/ComPWA/wiki/talks/Michel_CHEP10_10.pdf)   |
| DPG Frühjahrs-Tagung | 2011 | Münster       | [Partialwellenanalyse mit Geneva](https://github.com/ComPWA/ComPWA/wiki/talks/Michel_DPG11.pdf)         |
| PWA Summer School    | 2012 | Williamsburg  | [Common PWA Framework](https://github.com/ComPWA/ComPWA/wiki/talks/Jlab_PWA_12.pdf)                     |
| DPG Frühjahrs-Tagung | 2013 | Dresden       | [Common PWA framework for PANDA](https://github.com/ComPWA/ComPWA/wiki/talks/DPG_PWA13.pdf)             |
| CHEP                 | 2016 | San Francisco | [Common Partial Wave Analysis Framework](https://github.com/ComPWA/ComPWA/wiki/talks/CHEP16_Michel.pdf) |

<!-- markdownlint-enable -->

## Theses

<!-- markdownlint-disable -->

| Author           | Title                                                                                                                                                                                                                                                            | Type       | Year |
| ---------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ---------- | ---- |
| Mathias Michel   | Extraction of the scalar wave in $J/\Psi \rightarrow \gamma\pi^0\pi^0$using the ComPWA Framework ([pdf][michelthesis])                                                                                                                                           | PhD Thesis | 2016 |
| Peter Weidenkaff | Analysis of the decay $D_0 \rightarrow K^0_S K^+ K^-$ with theBESIII experiment ([pdf][weidenkaffthesis])                                                                                                                                                        | PhD Thesis | 2017 |
| Stefan Pflüger   | Precise determination of the luminosity with thePANDA-luminosity detector and implementation of the helicity formalism for the ComPWA framework for an extraction of the scalar wave in the channel$J/\Psi \rightarrow \gamma\pi^0\pi^0$ ([pdf][pfluegerthesis]) | PhD Thesis | 2017 |

<!-- markdownlint-enable -->

## Documents

```{eval-rst}
================= ===========================
Requirements 2012 `Requirement Specifications <https://github.com/ComPWA/ComPWA/wiki/pwa_requirements.pdf>`_
================= ===========================
```

[michelthesis]: http://nbn-resolving.org/urn:nbn:de:hebis:77-diss-1000005992
[pfluegerthesis]:
  https://hss-opus.ub.ruhr-uni-bochum.de/opus4/frontdoor/index/index/docId/5614
[talk1]: https://github.com/ComPWA/ComPWA/wiki/talks/Michel_DPG_PWA_03_12.pdf
[talk2]: https://github.com/ComPWA/ComPWA/wiki/talks/Michel_GD12.pdf
[talk3]: https://github.com/ComPWA/ComPWA/wiki/talks/Michel_AmpSchool_09_13.pdf
[talk4]: https://github.com/ComPWA/ComPWA/wiki/talks/Michel_CHEP_10_13.pdf
[talk5]: https://github.com/ComPWA/ComPWA/wiki/talks/DPG_PWA_14.pdf
[talk6]: https://github.com/ComPWA/ComPWA/wiki/talks/DPG_PWA_15.pdf
[weidenkaffthesis]:
  https://openscience.ub.uni-mainz.de/handle/20.500.12030/2783
